##  Step 1: Create a SAML Application
Follow these steps:
  1. In the OneLogin admin dashboard, in the Applications section, click Add App.
![Adding an Application in OneLogin](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274740867a44101485e48205fb02607a_LowRes.png)
Adding an Application in OneLogin
  2. On the page that appears, search for and select SAML Custom Connector (Advanced).
![Searching for SAML Custom Connector \(Advanced\)](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27444fcb7a4410148096e10731b714ce_LowRes.png)
Searching for SAML Custom Connector (Advanced)
  3. Enter a name for your application and adjust other settings as needed.
![Entering Basic Details for a SAML Application](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744e6d07a441014a0b9ebc50228b3fc_LowRes.png)
Entering Basic Details for a SAML Application
